Revision: 403
http://geany-plugins.svn.sourceforge.net/geany-plugins/?rev=403&view=rev
Author: frlan
Date: 2009-01-24 01:29:37 +0000 (Sat, 24 Jan 2009)
Log Message:
-----------
Created branch for redesign patch for geanyVC of Thomas Martitz
Added Paths:
-----------
branches/GeanyVC_menu_redesign/
Property changes on: branches/GeanyVC_menu_redesign
___________________________________________________________________
Added: svn:mergeinfo
+
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
Revision: 401
http://geany-plugins.svn.sourceforge.net/geany-plugins/?rev=401&view=rev
Author: yurand
Date: 2009-01-23 12:59:06 +0000 (Fri, 23 Jan 2009)
Log Message:
-----------
GeanyDoc: Added locale_init() function call
Modified Paths:
--------------
trunk/geanydoc/src/geanydoc.c
Modified: trunk/geanydoc/src/geanydoc.c
===================================================================
--- trunk/geanysendmail/README 2009-01-23 00:40:54 UTC (rev 399)
+++ trunk/geanysendmail/README 2009-01-23 00:41:26 UTC (rev 400)
@@ -77,6 +77,8 @@
several times. Examples could be:
sylpheed --attach "%f" --compose "%r"
mutt -s "Sending '%b'" -a "%f" "%r"
+ "C:\Program Files\Mozilla Thunderbird\thunderbird.exe" \
+ -compose to="%r",subject="%b",attachment="%f"
Development
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
Revision: 399
http://geany-plugins.svn.sourceforge.net/geany-plugins/?rev=399&view=rev
Author: frlan
Date: 2009-01-23 00:40:54 +0000 (Fri, 23 Jan 2009)
Log Message:
-----------
GeanySendMail: Added flag to W32 makefile, so plugin should also compile also on Windows Vista (Thanks to Timothy Boronczyk) for reporting.
Modified Paths:
--------------
trunk/geanysendmail/makefile.win32
Modified: trunk/geanysendmail/makefile.win32
===================================================================
--- trunk/geanysendmail/makefile.win32 2009-01-22 23:31:18 UTC (rev 398)
+++ trunk/geanysendmail/makefile.win32 2009-01-23 00:40:54 UTC (rev 399)
@@ -34,12 +34,12 @@
-I$(PREFIX)/include/gettext \
-I$(PREFIX)/include \
-I$(ASPELL_PREFIX)/interfaces/cc
-
+
ALL_GTK_LIBS= \
-L"$(PREFIX)/lib" \
-lgtk-win32-2.0 -lgdk-win32-2.0 -latk-1.0 -lgdk_pixbuf-2.0 -lpangowin32-1.0 -lgdi32 \
-lpango-1.0 -lgobject-2.0 -lgmodule-2.0 -lgthread-2.0 -lglib-2.0 -lintl -liconv
-CCFLAGS=-Wall -O2 -mms-bitfields -DHAVE_CONFIG_H
+CCFLAGS=-Wall -O2 -mms-bitfields -DHAVE_CONFIG_H -DLOCALEDIR=\"share\"
all: $(TARGET)
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
--- trunk/geanydoc/src/geanydoc.c 2009-01-23 00:41:26 UTC (rev 400)
+++ trunk/geanydoc/src/geanydoc.c 2009-01-23 12:59:06 UTC (rev 401)
@@ -41,6 +41,10 @@
#include "plugindata.h" /* this defines the plugin API */
#include "pluginmacros.h" /* some useful macros to avoid typing geany_data so often */
+#ifdef HAVE_LOCALE_H
+# include <locale.h>
+#endif
+
#include "geanydoc.h"
/* These items are set by Geany before init() is called. */
@@ -52,9 +56,9 @@
static GtkWidget *keyb2;
/* Check that Geany supports plugin API version 71 or later, and check
* for binary compatibility. */
-PLUGIN_VERSION_CHECK(78)
+PLUGIN_VERSION_CHECK(128)
/* All plugins must set name, description, version and author. */
PLUGIN_SET_INFO(_("Doc"), _("Call documentation viewer on current symbol."), VERSION,
_("Yura Siamshka <yurand2(a)gmail.com>"));
@@ -445,6 +449,7 @@
gchar *kb_label1 = _("Document current word");
gchar *kb_label2 = _("Document interactive");
+ p_main->locale_init(LOCALEDIR, GETTEXT_PACKAGE);
config_init();
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
Revision: 400
http://geany-plugins.svn.sourceforge.net/geany-plugins/?rev=400&view=rev
Author: frlan
Date: 2009-01-23 00:41:26 +0000 (Fri, 23 Jan 2009)
Log Message:
-----------
GeanySendMail: Added another example for using plugin with Thunderbird on Windows
Modified Paths:
--------------
trunk/geanysendmail/README
Modified: trunk/geanysendmail/README
===================================================================
@@ -52,9 +56,9 @@
static GtkWidget *keyb2;
-/* Check that Geany supports plugin API version 71 or later, and check
+/* Check that Geany supports plugin API version 128 or later, and check
* for binary compatibility. */